Bons and Furious
让你的优化整合包更进一步:在最佳性能模组之上实现更快的地形生成、更短的等待时间和更流畅的繁忙场景。300+ 项优化实现 9 倍世界生成、启动时间减少 56%、FPS 最高提升 17%。
截图
介绍

你的 CPU 一次一个 tick 地度过它的一生。
更快的世界。更流畅的繁忙场景。
Bons and Furious 减少了地形生成、加载、渲染和服务器 tick 背后的重复工作。它还修复了其所支持模组中的特定卡死和崩溃问题。将它与你现有的性能模组一起添加,每项优化和修复都有单独的开关。
在我们测试的 Forge 整合包中:世界生成吞吐量约提升 9×,进入新世界少等待 5½ 分钟,64 个动画生物下平均 FPS 提升 17%。
这些结果是在 Minecraft 1.20.1 上的 Bons and Furious 1.0.31 上于 2026 年 10 月 5 日测得的。它们不是对当前 1.0.48.1 版本或 NeoForge 构建的测量。
你将获得
- 更少等待地形。 复用地形计算和地面高度估算,而不是为相邻区块重复计算。在飞行测试中,使用 Bons 时平均 529 个附近区块中有 504 个已加载,而不使用时为 354 个。
- 更流畅的拥挤场景。 减少 Minecraft、Embeddium、Oculus、Entity Model Features、Entity Texture Features 及其他受支持模组中的重复动画、模型和渲染工作。匹配的 64 生物场景平均 FPS 提升 17%,1% 低帧提升 34%。
- 加载和保存时更少工作。 加速配方处理、资源加载、模型重建和区块序列化,并将受支持的存档数据和玩家文件写入移出服务器线程。
- 更少的首次生成尖峰和特定模组卡死。 在生物首次生成前准备其类,并修复已复现的线程和世界生成 bug。还阻止未加载的飞船区块继续 tick,并防止由引用缺失地形噪声的已保存规则导致的 TerraBlender 崩溃。第一夜的改进是单独用 1.0.35 测得的;详情见下文。
- 离开世界后占用更少内存。 释放 Distant Horizons、JEI、Flywheel、Smart Particles 及其他受支持模组中特定路径保留的旧世界和玩家。这些修复的是已复现的泄漏;它们不会消除所有内存增长来源。
在已优化的整合包上测得
双方都保留了 ModernFix、FerriteCore、Radium 和 C2ME。客户端还保留了 Embeddium、ImmediatelyFast 和 EntityCulling,以及 Oculus、Distant Horizons、Complementary 光影和 Fresh Animations。这些收益来自在该组合上添加 Bons and Furious。
2026 年 10 月 5 日 · Forge 1.20.1 · Bons and Furious 1.0.31 · 每组四次测量运行。 每次比较都使用同一台机器和匹配的设置,有和没有 Bons。下面的服务器和客户端结果来自不同的机器。
| 工作负载 | 无 Bons | 有 Bons 1.0.31 | 结果 |
|---|---|---|---|
| 生成 512 个区块,专用服务器 | 436 秒 | 48 秒 | 9.2× 吞吐量 |
| 启动游戏并进入新世界 | 588 秒 | 257 秒 | 少等待 56% |
| 64 个动画生物,平均 FPS | 54.6 | 64.0 | 提升 17% |
| 相同生物场景,1% 低帧 FPS | 31.4 | 42.1 | 提升 34% |
服务器:Core Ultra 9 285K。客户端:Ryzen 9 3900X / RTX 3080,1080p 加光影。C2ME 的 reduceLockRadius 已启用。FPS 测试使用同一存档,关闭 Distant Horizons 生成并完成 JEI 的后台工作。
生成还使用了 少 83% 的 CPU 时间 和每区块约 少 90% 的内存分配。那是更少的临时垃圾,而不是少 90% 的 RAM:启动后活动服务器堆在启用 Bons 时约高 30 MiB。
结果取决于整合包、设置和硬件。当 GPU 成为瓶颈时,CPU 节省可能只会带来少量额外 FPS。本次测试无法确定 1.0.31 比 1.0.26 快多少:机器和设置都变了。同一次运行中的 1.0.30 对比显示出相似的世界生成和稳定怪物场景 FPS。
深入了解各项改进
这些 Forge 1.20.1 示例解释了节省来自哪里。它们测量的是单个任务,而不是可以加到整包结果上的额外 FPS 或 TPS 增益。
| 位置 | 改动内容 | 实测结果 |
|---|---|---|
| 首夜生物生成 | 在生物首次生成前,于后台线程预先准备生物与 AI 类 | 在 1.0.35 版本、两颗 CPU 上的首夜测试中,超过 50 ms 的 tick 时间减少约四分之一。生成速率保持不变。 |
| Minecraft 区块生成 | 相邻区块的工作区域共享地面高度估算值,而不是重复扫描相同的列 | 跳过 95% 的地表扫描(144 区块的运行中从 349,843 降至 16,494),该次运行的实际耗时约减半(均值 162 → 75 秒,共享机器) |
| Minecraft 地形准备 | 密度图的第二遍处理复用第一遍构建的结果,而不是重新构建 | 每个 NoiseChunk 的 CPU 占用减少 91%(10.35 → 0.89 ms),每次结构放置高度查询减少 53%(17.7 → 8.3 ms) |
| Embeddium + Fusion | 在构建四边形之前跳过隐藏的连接纹理面 | 区块网格构建时间减少 25%(733 个区段从 5.2 → 3.9 秒),内存分配减少 41%,顶点与索引逐字节一致 |
| Farmer’s Delight | 工具动作类原料在配方加载期间共享其注册表扫描 | 客户端配方数据包解码 8.8 → 0.4 秒;配方重建在客户端 5.5–6.4 → 1.4 秒,在服务端 3.6 → 1.2 秒,原料相同 |
| Create | 装置碰撞箱一次性构建完成 | 400 格的载具 369 → 1.3 ms,内存 108 → 0.25 MB,碰撞箱完全一致 |
| Minecraft 存档 | 已保存数据与玩家文件由后台写入器压缩并写入 | 一次性处理 500 个数据文件时,服务端线程 4.9 → 0.9 秒,文件逐字节一致 |
| Minecraft 网络 | 数据包突发一次性刷新,而不是每个数据包刷新一次 | 300 次套接字刷新 → 1 次;网络线程 CPU 每包 8.7 → 2.6 µs,字节完全一致 |
| Embeddium | 当某次区段搜索的输入全部未变时,直接复用上一次的结果 | 静止镜头下每次搜索时间减少 58–68%;该搜索原本占渲染线程的 14.3% |
| Forge | 服务器列表状态中的模组与通道部分在未变化时被复用 | 440 个模组时每次状态更新 4.5 → 0.15 ms;在预生成期间它原本占服务端线程的 16.6% |
| Entity Model Features + Fresh Animations | 动画编译期间复用变量索引与模型部件查找结果 | 实体渲染器重建 15.1–16.6 → 8.8 秒,游戏中校验了 510 万次变量查询与 692,000 次部件查找 |
| Distant Horizons | 粗略表面生成器保留仅依赖 x 与 z 的地形密度部分,而不是在每个探测高度重新计算 | 每个 LOD 列时间减少 85%(3,351 → 494 µs) |
| Valkyrien Skies | 经过七轮飞船工作后的飞船区块记录管理 | 时间减少 94%(329 → 21 µs,完整整合包测试环境);物理地形转换减少 65–69% |
| Oculus | 空的光影渲染顺序图被复用而非重建 | 每次重置时间减少 90%(166 → 16 ns),内存 808 → 0 字节 |
| JEI | 每种原料保留其显示堆叠,过期语义相同 | 每次索引查找时间减少 84%(缓存测试中 830 → 130 ns);游戏内索引保留了相同的类别、配方与堆叠内容 |
| GeckoLib | 混合动画缓动不再使用装箱 double | 每次求值时间减少 50%(67 → 34 ns) |
| Architectury API | 事件分发不再重复解析方法句柄 | 快 19 倍(每次监听器调用 649 → 34 ns) |
| Forge + Oculus | 当光影包的层映射未变化时,每个方块记住其区块渲染层 | 每次查找时间减少 59%(122 → 50 ns),占区块网格构建的 12-14% |
| Radium 配合 C2ME | 在 C2ME 的替代实现关闭时,Radium 的快速区块访问重新启用 | 每次已加载区块查找时间减少 43%(81 → 46 ns),getBlockState 133 → 73 ns |
| Entity Texture Features | 每个精灵的纹理 id 只计算一次,而不是在每次绘制箱子、告示牌、床或旗帜时计算 | 每次绘制时间减少 95%(134 → 7 ns) |
| AmbientSounds | 有界地形扫描 | p95 降低 88%(每次分析 5.45 → 0.65 ms) |
| 帧节奏(客户端) | FPS 限制器的等待移至显示更新之前 | 在同样 120 FPS 上限下,p95 的帧间隔波动减少 84%(7.63 → 1.25 ms) |
| ImmediatelyFast | 马匹层排序不再使用子字符串 | 时间减少 46%(28.9 → 15.5 ns),内存 64 → 0 字节 |
| 资源包与数据包 | 文件夹列表使用索引,而不是反复遍历 ZIP | 在 1.0.46 测试中,3,472 次列表操作 305 → 11.9 ms。 |
| Minecraft + TerraBlender 生物群系搜索 | 复用同一次气候搜索中已计算的距离 | 在 1.0.46 记录的整合包工作负载中,每次搜索时间减少 13%。 |
| Quark + Zeta 石簇 | 在读取簇外方块之前先检测簇形状 | 在 1.0.46 测试中,每个被石簇触及的区块时间减少 26.9%。 |
| Distant Horizons、JEI、Flywheel 与 Smart Particles | 释放修复后的缓存与菜单所持有的旧世界引用 | 在 1.0.46 检查中,经过六次维度切换与三次重连后,修复后的持有者未保留任何旧世界。其他持有者仍然存在。 |
| Valkyrien Skies 区块清理 | 在不再需要时卸载客户端飞船方块实体与世界区块 | 修复了四次重访后169 方块实体飞船累积 845 个 ticker 的复现问题,以及服务端卸载后世界区块仍继续 tick 的问题(1.0.46)。 |
| TerraBlender 已保存的地表规则 | 跳过因模组改动而需要移除地形噪声的过时已保存规则;保留当前规则 | 在 1.0.47 缺失噪声测试中,无修复时 16 个区块全部失败;有修复时 16 个全部生成。这是崩溃修复,不是速度测量。 |
生物预热会多占用约 7 MB 的类内存,并使单人游戏加入时间增加约半秒。其他控制项减少了区块保存分配、物品栏进度检查、空闲生物与镜头晃动扫描,以及 Cataclysm 和 Mekanism 等模组中的重复工作。上述 1.0.46 和 1.0.47 示例是独立检查,并非新的整包基准测试。Distant Horizons 和 Valkyrien Skies 仍有其他路径会保留旧世界。详情与剩余限制。
选择你的构建
| Minecraft | 加载器 | 控制项 | 要求 |
|---|---|---|---|
| 1.20.1 | Forge | 384 | Forge 47.3.22 或更新版本 |
| 1.21.1 | NeoForge | 260 | Java 21;NeoForge 21.1.252 或更新版本 |
每个构建的客户端和服务端共用一个 JAR,且无需目标模组。不同构建的覆盖范围不同;上述数据为 Forge 1.20.1 的测量结果。
Forge 构建包含 322 项优化、57 项修复和 5 项有意的行为变更。这五项控制包括帧节奏和实验性 Radium 选项;它们的取舍已逐项记录。全部 384 项控制列于 config/bons_and_furious.properties。要禁用某一项,将其键设为 false 并重启。
Forge 1.20.1 覆盖的模组(均为可选)
渲染、光影与氛围: Embeddium、Oculus、ImmediatelyFast、Entity Texture Features、Entity Model Features、EntityCulling、Fusion、Colorwheel、Ryoamic Lights、Presence Footsteps、AmbientSounds、CIT Reforged、FancyMenu、Particular、Subtle Effects、Smart Particles、Punchy。
共享前置库与服务端性能模组: GeckoLib、Architectury API、Curios API、Structure Gel API、Radium、ModernFix、ChunkSending、TerraBlender、Citadel、Lionfish API、Placebo、Kiwi、Cucumber、CoFH Core、L2 Library、Pehkui、Almost Unified、ElysiumAPI、Zeta、Flywheel、AzureLib、Knight Lib、LDLib、Advanced Wall Climber API、Item Filters、Text Animator。
船只、结构与远景地形: Valkyrien Skies、Trackwork、Distant Horizons、Structurify、Sakes Structures、Oh The Biomes We’ve Gone、Dynamic Trees。
内容与玩法: Alex’s Caves、Ice and Fire、新生魔艺、JEI物品管理器、农夫乐事、Relics、Timeless and Classics Zero (TaCZ)、Terramity、Ad Astra、Fowl Play、Butterflies、Goblins Tyranny、Under the Moon、Nether Depths Upgrade、Spawn、Cryptic Foes、Hostile Villages、Scuba Gear、Occult、Scorched 和 Better Combat、机械动力、Pipez、储物抽屉、沉浸工程、Slice & Dice、Cooking for Blockheads、Alex’s Mobs、Mowzie’s Mobs、Mutant Monsters、Critters and Companions、Bosses of Mass Destruction、FD Bosses、Legendary Monsters、Ribbits、Artifacts、Simply Swords、SlashBlade: Resharped、Dungeons Delight、Jaden’s Nether Expansion、Regions Unexplored、L_Ender’s Cataclysm、通用机械、Rats、Aquaculture、XercaPaint、植物魔法、Reliquary、Immersive Aircraft、Born in Chaos、Luminous Beasts、Rustic Engineer、Unique Dungeons、More Artifacts、Nature’s Aura、L2 Hostility、Species、Celestisynth、Brutality、Clanging Howl、TreeChop、Cable Facades。
覆盖范围指已测试的构建及每个模组的特定代码路径,而非全部功能。每个模组的已测试构建:兼容性与目标版本。
安装匹配的构建
对于 Minecraft 1.21.1,请使用 bons_and_furious-neoforge-1.0.47+mc1.21.1.jar、Java 21 和 NeoForge 21.1.252 或更新版本。MixinSquared 已内置;NeoForge 提供 MixinExtras。NeoForge 安装与兼容性。
对于 Minecraft 1.20.1 / Forge:
- 从“文件”标签页下载
bons_and_furious-1.0.48.1.jar,并将其放入客户端和服务端的mods/中。无需其他操作;所有目标模组都会在加载时被检测到。它使用的两个小型 mixin 前置库 MixinExtras 和 MixinSquared 已内置其中。 - 启动一次。模组会写入其默认配置(除
jei_join_recipe_deferral、radium_experimental_tickets_spawning和vanilla_background_level_dat外,所有开关均开启),并记录启用了多少项控制。 - 要关闭某一项,将其键设为
false并重启。仅客户端补丁(渲染器、光影、环境氛围)在专用服务端上永远不会加载。
JVM 覆盖、日志消息和故障排除:安装与配置。
兼容性
保留你的优化模组栈:Embeddium、ImmediatelyFast、ModernFix、FerriteCore、Radium 和 C2ME。Bons and Furious 会更改在测试整合包中仍在做不必要工作的路径,包括 Embeddium、ImmediatelyFast 和 Oculus 自身内部的一些路径。安装 C2ME 后,它还会为 Radium 和 ModernFix 恢复三项优化,而它们会为每个 C2ME 构建关闭这些优化,只要在c2me.toml中关闭了会与各自冲突的 C2ME 模块。
在已包含其中八项更改的较新 Forge、JEI 和 ModernFix 构建上,相应的 Bons 控制会自动让位。使用 Collections Of Optimizations 时,共享控制还会检查哪个实现处于活动状态,以免同一项优化被应用两次或在两个模组中都被禁用。兼容性详情。
源码、许可证与回馈
采用 GPL-3.0-only 许可证,并保留上游署名和声明。源码与构建说明 · Wiki · 报告问题
上游拉取请求
发送给此模组所修补项目的拉取请求:13 个已合并,83 个开放,18 个已关闭且未合并(状态检查于 2026 年 10 月 23 日)。
| 项目 | 拉取请求 | 状态 |
|---|---|---|
| Ad Astra | #825 | 开放 |
| Alex’s Caves | #1759、#1760、#1762 | 开放 |
| Alex’s Mobs | #2385、#2386 | 开放 |
| Almost Unified | #144 | 已关闭且未合并 |
| AmbientSounds | #348、#349 | 已合并 |
| Architectury API | #747 | 开放 |
| 新生魔艺 | #2258 | 已关闭且未合并 |
| Artifacts | #518 | 开放 |
| Baked Substring Index | #1 | 开放 |
| Better Combat | #623 | 开放 |
| Bosses of Mass Destruction Forge | #31 | 开放 |
| Butterflies | #493 | 已合并 |
| ChunkSending | #13 | 已关闭且未合并 |
| CIT Reforged | #16 | 开放 |
| Citadel | #232 | 开放 |
| Colorwheel | #84 | 开放 |
| Cooking for Blockheads | #812 | 开放 |
| Cryptic Foes | #7 | 已关闭且未合并 |
| Cucumber Library | #62 | 开放 |
| Curios API | #639、#644、#645 | 开放 |
| Dungeon’s Delight | #126 | 开放 |
| Dynamic Trees | #1230、#1231 | 开放 |
| Embeddium | #575、#576、#577、#578、#579、#580、#581 | 开放 |
| Entity Model Features | #591、#592 | 已合并 |
| Entity Texture Features | #508 | 已合并 |
| 农夫乐事 | #1397、#1398 | 开放 |
| FDBosses | #42 | 开放 |
| Forge | #10893、#10894、#10899 | 已合并 |
| Forge | #10895 | 已关闭且未合并。已撤回,改为采用 26.3 分支上的 #10899,并采用维护者要求的设计。 |
| Forge | #10896 | 已关闭且未合并。已撤回:#10893 之后已无多少收益。 |
| Fowl Play | #242、#243 | 开放 |
| Fusion | #316、#317、#318 | 开放 |
| Hostile Villages | #37、#38 | 开放 |
| Ice and Fire | #5641、#5642、#5643、#5644、#5645 | 开放 |
| ImmediatelyFast | #586、#588、#589 | 已关闭且未合并 |
| 沉浸工程 | #6448 | 开放 |
| Jaden’s Nether Expansion | #353 | 已关闭且未合并。已撤回:1.20.1 分支不再维护,且 1.21.1 的重做已涵盖该内容。 |
| JEI物品管理器 | #4525 | 已合并。已在 JEI 15.62.0.218 中发布。 |
| JEI物品管理器 | #4527 | 已关闭且未合并。已撤回:它不符合该缓存的用途。 |
| L2 Library | #34、#35 | 开放 |
| Legendary Monsters | #13 | 开放 |
| Lionfish API | #5、#6 | 开放 |
| ModernFix | #696 | 已合并 |
| ModernFix | #697、#698、#699 | 已关闭且未合并 |
| Mowzie’s Mobs | #65 | 开放 |
| Mutant Monsters | #139 | 开放 |
| Nether Depths Upgrade | #67 | 已关闭且未合并。1.20 分支不再维护。 |
| OcclusionCulling (EntityCulling) | #5 | 已合并 |
| Oculus | #869、#870、#871、#872 | 开放 |
| Oh The Biomes We’ve Gone | #421 | 开放 |
| Particular | #59 | 开放 |
| Pehkui | #636 | 开放 |
| Placebo | #125 | 已关闭且未合并。1.20 分支不再维护;较新分支已移除该事件。 |
| Presence Footsteps (Forge) | #67 | 开放 |
| Radium Re-Reforged | #8 | 已关闭且未合并 |
| Radium Re-Reforged | #9、#11、#15、#16、#17、#18 | 开放 |
| Regions Unexplored | #234 | 开放 |
| Relics | #357、#358 | 开放 |
| Ribbits | #85 | 开放 |
| Ryoamic Lights | #54、#55 | 开放 |
| Smart Particles | #10 | 开放 |
| Species | #91 | 开放 |
| 储物抽屉 | #1307 | 开放 |
| Structurify | #93 | 已关闭且未合并 |
| TerraBlender | #241 | 已合并 |
| Timeless and Classics Zero (TaCZ) | #745 | 开放 |
| Trackwork | #70 | 开放 |
| Valkyrien Skies | #1981、#1982、#1983、#1984、#1985、#1997 | 开放 |
作者与致谢
大部分代码由他人编写。AI 协助完成了部分代码、测试、打包和文档工作。原模组作者保留对其作品的署名权。
项目标志是 AI 生成的宣传概念图,并不描绘本模组添加的内容。
常见问题
Bons and Furious 支持哪些 Minecraft 版本?
Bons and Furious 支持 Minecraft Java 版 1.20.1–1.21.1,共 2 个版本,可用的加载器:Forge / NeoForge。下载时注意选择和你游戏版本一致的文件。
Bons and Furious 怎么安装?
先用 PCL2 或 HMCL 启动器安装对应版本的 Forge / NeoForge,再把下载的 .jar 文件放进游戏目录的 mods 文件夹,重新启动游戏即可。开启了版本隔离的,mods 文件夹在 versions/版本名 下面。
评论
登录后评论和评分